/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.database.data;

import java.io.Serializable;

import org.apache.commons.lang3.StringUtils;

public class FileData
    implements Serializable
{

    private static final long serialVersionUID = 7578770469073055878L;

    public static final String NEW_DATA = StringUtils.EMPTY;

    private String day = NEW_DATA;

    private String month = NEW_DATA;

    private String name = NEW_DATA;

    private String size = NEW_DATA;

    private String yearOrTime = NEW_DATA;

    public FileData()
    {
        // nothing to do
    }

    public FileData( String name, String size, String month, String day, String yearTime )
    {
        setName( name );
        setSize( size );
        setMonth( month );
        setDay( day );
        setYearOrTime( yearTime );
    }

    public String getDay()
    {
        return day;
    }

    public void setDay( String day )
    {
        this.day = day;
    }

    public String getMonth()
    {
        return month;
    }

    public void setMonth( String month )
    {
        this.month = month;
    }

    public String getName()
    {
        return name;
    }

    public void setName( String name )
    {
        this.name = name;
    }

    public String getSize()
    {
        return size;
    }

    public void setSize( String size )
    {
        this.size = size;
    }

    public String getYearOrTime()
    {
        return yearOrTime;
    }

    public void setYearOrTime( String yearOrTime )
    {
        this.yearOrTime = yearOrTime;
    }

    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + ( ( day == null ) ? 0 : day.hashCode() );
        result = prime * result + ( ( month == null ) ? 0 : month.hashCode() );
        result = prime * result + ( ( name == null ) ? 0 : name.hashCode() );
        result = prime * result + ( ( size == null ) ? 0 : size.hashCode() );
        result = prime * result + ( ( yearOrTime == null ) ? 0 : yearOrTime.hashCode() );
        return result;
    }

    @Override
    public boolean equals( Object obj )
    {
        if ( this == obj )
        {
            return true;
        }
        if ( obj == null )
        {
            return false;
        }
        if ( !( obj instanceof FileData ) )
        {
            return false;
        }
        FileData other = (FileData) obj;
        if ( day == null )
        {
            if ( other.day != null )
            {
                return false;
            }
        }
        else if ( !day.equals( other.day ) )
        {
            return false;
        }
        if ( month == null )
        {
            if ( other.month != null )
            {
                return false;
            }
        }
        else if ( !month.equals( other.month ) )
        {
            return false;
        }
        if ( name == null )
        {
            if ( other.name != null )
            {
                return false;
            }
        }
        else if ( !name.equals( other.name ) )
        {
            return false;
        }
        if ( size == null )
        {
            if ( other.size != null )
            {
                return false;
            }
        }
        else if ( !size.equals( other.size ) )
        {
            return false;
        }
        if ( yearOrTime == null )
        {
            if ( other.yearOrTime != null )
            {
                return false;
            }
        }
        else if ( !yearOrTime.equals( other.yearOrTime ) )
        {
            return false;
        }
        return true;
    }

}
