/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.database.data;

import java.io.Serializable;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

import org.apache.commons.lang3.StringUtils;

@Entity( name = "ServersGroupData" )
@Table( name = "dv_servers_group", uniqueConstraints = { @UniqueConstraint( columnNames = { "name" } ) } )
public class ServersGroupData
    implements Serializable
{

    private static final long serialVersionUID = 1902918910036293087L;

    public static final long NEW_SERVERS_GROUP = 0;

    public static final long UNDEFINED_SERVERS_GROUP = -1;

    public static final Boolean DEFAULT_ENABLED = Boolean.TRUE;

    public static final String NEW_DATA = StringUtils.EMPTY;

    @Id
    @GeneratedValue( strategy = GenerationType.AUTO )
    private Long id;

    @Column( name = "name", length = 100, nullable = false )
    private String name;

    @Column( name = "note", length = 200, nullable = true )
    private String note;

    @Column( name = "enabled", nullable = false )
    private Boolean enabled;

    @ManyToMany( fetch = FetchType.EAGER )
    @JoinTable( name = "dv_servers_group_server", //
                    joinColumns = { @JoinColumn( name = "servers_group_id", referencedColumnName = "id" ) }, //
                    inverseJoinColumns = { @JoinColumn( name = "server_id", referencedColumnName = "id" ) } )
    private List<ServerData> serverDatas;

    public ServersGroupData()
    {
        setEnabled( DEFAULT_ENABLED );
    }

    public ServersGroupData( long id, String name, String note, boolean enabled, List<ServerData> serverDatas )
    {
        setId( id );
        setName( name );
        setNote( note );
        setEnabled( enabled );
        setServerDatas( serverDatas );
    }

    public Long getId()
    {
        return id;
    }

    public void setId( Long id )
    {
        this.id = id;
    }

    public String getName()
    {
        return name;
    }

    public void setName( String name )
    {
        this.name = StringUtils.stripToEmpty( name );
    }

    public String getNote()
    {
        return note;
    }

    public void setNote( String note )
    {
        this.note = StringUtils.stripToEmpty( note );
    }

    public Boolean isEnabled()
    {
        return enabled;
    }

    public void setEnabled( Boolean enabled )
    {
        this.enabled = enabled;
    }

    public List<ServerData> getServerDatas()
    {
        return serverDatas;
    }

    public void setServerDatas( List<ServerData> serverDatas )
    {
        this.serverDatas = serverDatas;
    }

    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + ( ( enabled == null ) ? 0 : enabled.hashCode() );
        result = prime * result + ( ( id == null ) ? 0 : id.hashCode() );
        result = prime * result + ( ( name == null ) ? 0 : name.hashCode() );
        result = prime * result + ( ( note == null ) ? 0 : note.hashCode() );
        return result;
    }

    @Override
    public boolean equals( Object obj )
    {
        if ( this == obj )
        {
            return true;
        }
        if ( obj == null )
        {
            return false;
        }
        if ( !( obj instanceof ServersGroupData ) )
        {
            return false;
        }
        ServersGroupData other = (ServersGroupData) obj;
        if ( enabled == null )
        {
            if ( other.enabled != null )
            {
                return false;
            }
        }
        else if ( !enabled.equals( other.enabled ) )
        {
            return false;
        }
        if ( id == null )
        {
            if ( other.id != null )
            {
                return false;
            }
        }
        else if ( !id.equals( other.id ) )
        {
            return false;
        }
        if ( name == null )
        {
            if ( other.name != null )
            {
                return false;
            }
        }
        else if ( !name.equals( other.name ) )
        {
            return false;
        }
        if ( note == null )
        {
            if ( other.note != null )
            {
                return false;
            }
        }
        else if ( !note.equals( other.note ) )
        {
            return false;
        }
        return true;
    }

}
