/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.database.orders;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Root;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.dussan.vaadin.dvirtual.database.columns.ServersGroupColumns;
import org.dussan.vaadin.dvirtual.database.data.ServersGroupData;
import org.dussan.vaadin.dvirtual.database.data.ServersGroupData_;

public class ServersGroupOrder
    implements Serializable
{

    private static final long serialVersionUID = 1844343669649842526L;

    public static final CriteriaQuery<ServersGroupData> addOrder( CriteriaBuilder criteriaBuilder, CriteriaQuery<ServersGroupData> criteriaQuery, Root<ServersGroupData> serversGroup,
                                                                  List<String> orders )
    {
        if ( CollectionUtils.isNotEmpty( orders ) )
        {
            List<Order> criteriaOrders = new ArrayList<>();
            for ( String order : orders )
            {
                if ( StringUtils.equals( order, ServersGroupColumns.ENABLED.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( serversGroup.get( ServersGroupData_.enabled ) ) );
                }
                else if ( StringUtils.equals( order, ServersGroupColumns.ENABLED.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( serversGroup.get( ServersGroupData_.enabled ) ) );
                }
                else if ( StringUtils.equals( order, ServersGroupColumns.NAME.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( serversGroup.get( ServersGroupData_.name ) ) );
                }
                else if ( StringUtils.equals( order, ServersGroupColumns.NAME.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( serversGroup.get( ServersGroupData_.name ) ) );
                }
                else if ( StringUtils.equals( order, ServersGroupColumns.NOTE.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( serversGroup.get( ServersGroupData_.note ) ) );
                }
                else if ( StringUtils.equals( order, ServersGroupColumns.NOTE.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( serversGroup.get( ServersGroupData_.note ) ) );
                }
            }
            return criteriaQuery.orderBy( criteriaOrders );
        }
        else
        {
            return criteriaQuery.orderBy( criteriaBuilder.asc( serversGroup.get( ServersGroupData_.name ) ) );
        }
    }

}
