/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.info;

import org.apache.commons.lang3.StringUtils;

public enum ApplicationLocale
{

    AA_ER_SAAHO( "Eritrea", "Afar", "aa_ER@saaho.UTF-8" ),
    AA_ER( "Eritrea", "Afar", "aa_ER.UTF-8" ),
    AA_ET( "Ethiopia", "Afar", "aa_ET.UTF-8" ),
    AF_ZA( "South Africa", "Afrikaans", "af_ZA.UTF-8" ),
    AGR_PE( "Peru", "Aguaruna", "agr_PE.UTF-8" ),
    AK_GH( "Ghana", "Akan", "ak_GH.UTF-8" ),
    AM_ET( "Ethiopia", "Amharic", "am_ET.UTF-8" ),
    AN_ES( "Spain", "Aragonese", "an_ES.UTF-8" ),
    ANP_IN( "India", "Angika", "anp_IN.UTF-8" ),
    AR_AE( "United Arab Emirates", "Arabic", "ar_AE.UTF-8" ),
    AR_BH( "Bahrain", "Arabic", "ar_BH.UTF-8" ),
    AR_DZ( "Algeria", "Arabic", "ar_DZ.UTF-8" ),
    AR_EG( "Egypt", "Arabic", "ar_EG.UTF-8" ),
    AR_IN( "India", "Arabic", "ar_IN.UTF-8" ),
    AR_IQ( "Iraq", "Arabic", "ar_IQ.UTF-8" ),
    AR_JO( "Jordan", "Arabic", "ar_JO.UTF-8" ),
    AR_KW( "Kuwait", "Arabic", "ar_KW.UTF-8" ),
    AR_LB( "Lebanon", "Arabic", "ar_LB.UTF-8" ),
    AR_LY( "Libya", "Arabic", "ar_LY.UTF-8" ),
    AR_MA( "Morocco", "Arabic", "ar_MA.UTF-8" ),
    AR_OM( "Oman", "Arabic", "ar_OM.UTF-8" ),
    AR_QA( "Qatar", "Arabic", "ar_QA.UTF-8" ),
    AR_SA( "Saudi Arabia", "Arabic", "ar_SA.UTF-8" ),
    AR_SD( "Sudan", "Arabic", "ar_SD.UTF-8" ),
    AR_SS( "South Sudan", "Arabic", "ar_SS.UTF-8" ),
    AR_SY( "Syria", "Arabic", "ar_SY.UTF-8" ),
    AR_TN( "Tunisia", "Arabic", "ar_TN.UTF-8" ),
    AR_YE( "Yemen", "Arabic", "ar_YE.UTF-8" ),
    AS_IN( "India", "Assamese", "as_IN.UTF-8" ),
    AST_ES( "Spain", "Asturian", "ast_ES.UTF-8" ),
    AYC_PE( "Peru", "Aymara", "ayc_PE.UTF-8" ),
    AZ_AZ( "Azerbaijan", "Azerbaijani", "az_AZ.UTF-8" ),
    AZ_IR( "Iran", "South Azerbaijani", "az_IR.UTF-8" ),
    BE_BY_LATIN( "Belarus", "Belarusian", "be_BY@latin.UTF-8" ),
    BE_BY( "Belarus", "Belarusian", "be_BY.UTF-8" ),
    BEM_ZM( "Zambia", "Bemba", "bem_ZM.UTF-8" ),
    BER_DZ( "Algeria", "Berber", "ber_DZ.UTF-8" ),
    BER_MA( "Morocco", "Berber", "ber_MA.UTF-8" ),
    BG_BG( "Bulgaria", "Bulgarian", "bg_BG.UTF-8" ),
    BHB_IN( "India", "Bhili", "bhb_IN.UTF-8" ),
    BHO_IN( "India", "Bhojpuri", "bho_IN.UTF-8" ),
    BHO_NP( "Nepal", "Bhojpuri", "bho_NP.UTF-8" ),
    BI_VU( "Vanuatu", "Bislama", "bi_VU.UTF-8" ),
    BN_BD( "Bangladesh", "Bangla", "bn_BD.UTF-8" ),
    BN_IN( "India", "Bangla", "bn_IN.UTF-8" ),
    BO_CN( "China", "Tibetan", "bo_CN.UTF-8" ),
    BO_IN( "India", "Tibetan", "bo_IN.UTF-8" ),
    BR_FR_EURO( "France", "Breton", "br_FR@euro.UTF-8" ),
    BR_FR( "France", "Breton", "br_FR.UTF-8" ),
    BRX_IN( "India", "Bodo", "brx_IN.UTF-8" ),
    BS_BA( "Bosnia & Herzegovina", "Bosnian", "bs_BA.UTF-8" ),
    BYN_ER( "Eritrea", "Blin", "byn_ER.UTF-8" ),
    CA_AD( "Andorra", "Catalan", "ca_AD.UTF-8" ),
    CA_ES_EURO( "Spain", "Catalan", "ca_ES@euro.UTF-8" ),
    CA_ES_VALENCIA( "Spain", "Catalan", "ca_ES@valencia.UTF-8" ),
    CA_ES( "Spain", "Catalan", "ca_ES.UTF-8" ),
    CA_FR( "France", "Catalan", "ca_FR.UTF-8" ),
    CA_IT( "Italy", "Catalan", "ca_IT.UTF-8" ),
    CE_RU( "Russia", "Chechen", "ce_RU.UTF-8" ),
    CHR_US( "United States", "Cherokee", "chr_US.UTF-8" ),
    CMN_TW( "Taiwan", "Mandarin Chinese", "cmn_TW.UTF-8" ),
    CRH_UA( "Ukraine", "Crimean Tatar", "crh_UA.UTF-8" ),
    CS_CZ( "Czech Republic", "Czech", "cs_CZ.UTF-8" ),
    CSB_PL( "Poland", "Kashubian", "csb_PL.UTF-8" ),
    CV_RU( "Russia", "Chuvash", "cv_RU.UTF-8" ),
    CY_GB( "United Kingdom", "Welsh", "cy_GB.UTF-8" ),
    DA_DK( "Denmark", "Danish", "da_DK.UTF-8" ),
    DE_AT_EURO( "Austria", "German", "de_AT@euro.UTF-8" ),
    DE_AT( "Austria", "Austrian German", "de_AT.UTF-8" ),
    DE_BE_EURO( "Belgium", "German", "de_BE@euro.UTF-8" ),
    DE_BE( "Belgium", "German", "de_BE.UTF-8" ),
    DE_CH( "Switzerland", "Swiss High German", "de_CH.UTF-8" ),
    DE_DE_EURO( "Germany", "German", "de_DE@euro.UTF-8" ),
    DE_DE( "Germany", "German", "de_DE.UTF-8" ),
    DE_IT( "Italy", "German", "de_IT.UTF-8" ),
    DE_LI( "Liechtenstein", "German", "de_LI.UTF-8" ),
    DE_LU_EURO( "Luxembourg", "German", "de_LU@euro.UTF-8" ),
    DE_LU( "Luxembourg", "German", "de_LU.UTF-8" ),
    DOI_IN( "India", "Dogri", "doi_IN.UTF-8" ),
    DSB_DE( "Germany", "Lower Sorbian", "dsb_DE.UTF-8" ),
    DV_MV( "Maldives", "Divehi", "dv_MV.UTF-8" ),
    DZ_BT( "Bhutan", "Dzongkha", "dz_BT.UTF-8" ),
    EL_CY( "Cyprus", "Greek", "el_CY.UTF-8" ),
    EL_GR_EURO( "Greece", "Greek", "el_GR@euro.UTF-8" ),
    EL_GR( "Greece", "Greek", "el_GR.UTF-8" ),
    EN_AG( "Antigua & Barbuda", "English", "en_AG.UTF-8" ),
    EN_AU( "Australia", "Australian English", "en_AU.UTF-8" ),
    EN_BW( "Botswana", "English", "en_BW.UTF-8" ),
    EN_CA( "Canada", "Canadian English", "en_CA.UTF-8" ),
    EN_DK( "Denmark", "English", "en_DK.UTF-8" ),
    EN_GB( "United Kingdom", "British English", "en_GB.UTF-8" ),
    EN_HK( "Hong Kong SAR China", "English", "en_HK.UTF-8" ),
    EN_IE_EURO( "Ireland", "English", "en_IE@euro.UTF-8" ),
    EN_IE( "Ireland", "English", "en_IE.UTF-8" ),
    EN_IL( "Israel", "English", "en_IL.UTF-8" ),
    EN_IN( "India", "English", "en_IN.UTF-8" ),
    EN_NG( "Nigeria", "English", "en_NG.UTF-8" ),
    EN_NZ( "New Zealand", "English", "en_NZ.UTF-8" ),
    EN_PH( "Philippines", "English", "en_PH.UTF-8" ),
    EN_SC( "Seychelles", "English", "en_SC.UTF-8" ),
    EN_SG( "Singapore", "English", "en_SG.UTF-8" ),
    EN_US( "United States", "American English", "en_US.UTF-8" ),
    EN_ZA( "South Africa", "English", "en_ZA.UTF-8" ),
    EN_ZM( "Zambia", "English", "en_ZM.UTF-8" ),
    EN_ZW( "Zimbabwe", "English", "en_ZW.UTF-8" ),
    ES_AR( "Argentina", "Spanish", "es_AR.UTF-8" ),
    ES_BO( "Bolivia", "Spanish", "es_BO.UTF-8" ),
    ES_CL( "Chile", "Spanish", "es_CL.UTF-8" ),
    ES_CO( "Colombia", "Spanish", "es_CO.UTF-8" ),
    ES_CR( "Costa Rica", "Spanish", "es_CR.UTF-8" ),
    ES_CU( "Cuba", "Spanish", "es_CU.UTF-8" ),
    ES_DO( "Dominican Republic", "Spanish", "es_DO.UTF-8" ),
    ES_EC( "Ecuador", "Spanish", "es_EC.UTF-8" ),
    ES_ES_EURO( "Spain", "Spanish", "es_ES@euro.UTF-8" ),
    ES_ES( "Spain", "European Spanish", "es_ES.UTF-8" ),
    ES_GT( "Guatemala", "Spanish", "es_GT.UTF-8" ),
    ES_HN( "Honduras", "Spanish", "es_HN.UTF-8" ),
    ES_MX( "Mexico", "Mexican Spanish", "es_MX.UTF-8" ),
    ES_NI( "Nicaragua", "Spanish", "es_NI.UTF-8" ),
    ES_PA( "Panama", "Spanish", "es_PA.UTF-8" ),
    ES_PE( "Peru", "Spanish", "es_PE.UTF-8" ),
    ES_PR( "Puerto Rico", "Spanish", "es_PR.UTF-8" ),
    ES_PY( "Paraguay", "Spanish", "es_PY.UTF-8" ),
    ES_SV( "El Salvador", "Spanish", "es_SV.UTF-8" ),
    ES_US( "United States", "Spanish", "es_US.UTF-8" ),
    ES_UY( "Uruguay", "Spanish", "es_UY.UTF-8" ),
    ES_VE( "Venezuela", "Spanish", "es_VE.UTF-8" ),
    ET_EE( "Estonia", "Estonian", "et_EE.UTF-8" ),
    EU_ES_EURO( "Spain", "Basque", "eu_ES@euro.UTF-8" ),
    EU_ES( "Spain", "Basque", "eu_ES.UTF-8" ),
    EU_FR_EURO( "France", "Basque", "eu_FR@euro.UTF-8" ),
    EU_FR( "France", "Basque", "eu_FR.UTF-8" ),
    FA_IR( "Iran", "Persian", "fa_IR.UTF-8" ),
    FF_SN( "Senegal", "Fulah", "ff_SN.UTF-8" ),
    FI_FI_EURO( "Finland", "Finnish", "fi_FI@euro.UTF-8" ),
    FI_FI( "Finland", "Finnish", "fi_FI.UTF-8" ),
    FIL_PH( "Philippines", "Filipino", "fil_PH.UTF-8" ),
    FO_FO( "Faroe Islands", "Faroese", "fo_FO.UTF-8" ),
    FR_BE_EURO( "Belgium", "French", "fr_BE@euro.UTF-8" ),
    FR_BE( "Belgium", "French", "fr_BE.UTF-8" ),
    FR_CA( "Canada", "Canadian French", "fr_CA.UTF-8" ),
    FR_CH( "Switzerland", "Swiss French", "fr_CH.UTF-8" ),
    FR_FR_EURO( "France", "French", "fr_FR@euro.UTF-8" ),
    FR_FR( "France", "French", "fr_FR.UTF-8" ),
    FR_LU_EURO( "Luxembourg", "French", "fr_LU@euro.UTF-8" ),
    FR_LU( "Luxembourg", "French", "fr_LU.UTF-8" ),
    FUR_IT( "Italy", "Friulian", "fur_IT.UTF-8" ),
    FY_DE( "Germany", "Western Frisian", "fy_DE.UTF-8" ),
    FY_NL( "Netherlands", "Western Frisian", "fy_NL.UTF-8" ),
    GA_IE_EURO( "Ireland", "Irish", "ga_IE@euro.UTF-8" ),
    GA_IE( "Ireland", "Irish", "ga_IE.UTF-8" ),
    GD_GB( "United Kingdom", "Scottish Gaelic", "gd_GB.UTF-8" ),
    GEZ_ER_ABEGEDE( "Eritrea", "Geez", "gez_ER@abegede.UTF-8" ),
    GEZ_ER( "Eritrea", "Geez", "gez_ER.UTF-8" ),
    GEZ_ET_ABEGEDE( "Ethiopia", "Geez", "gez_ET@abegede.UTF-8" ),
    GEZ_ET( "Ethiopia", "Geez", "gez_ET.UTF-8" ),
    GL_ES_EURO( "Spain", "Galician", "gl_ES@euro.UTF-8" ),
    GL_ES( "Spain", "Galician", "gl_ES.UTF-8" ),
    GU_IN( "India", "Gujarati", "gu_IN.UTF-8" ),
    GV_GB( "United Kingdom", "Manx", "gv_GB.UTF-8" ),
    HA_NG( "Nigeria", "Hausa", "ha_NG.UTF-8" ),
    HAK_TW( "Taiwan", "Hakka Chinese", "hak_TW.UTF-8" ),
    HE_IL( "Israel", "Hebrew", "he_IL.UTF-8" ),
    HI_IN( "India", "Hindi", "hi_IN.UTF-8" ),
    HIF_FJ( "Fiji", "Fiji Hindi", "hif_FJ.UTF-8" ),
    HNE_IN( "India", "Chhattisgarhi", "hne_IN.UTF-8" ),
    HR_HR( "Croatia", "Croatian", "hr_HR.UTF-8" ),
    HSB_DE( "Germany", "Upper Sorbian", "hsb_DE.UTF-8" ),
    HT_HT( "Haiti", "Haitian Creole", "ht_HT.UTF-8" ),
    HU_HU( "Hungary", "Hungarian", "hu_HU.UTF-8" ),
    HY_AM( "Armenia", "Armenian", "hy_AM.UTF-8" ),
    IA_FR( "France", "Interlingua", "ia_FR.UTF-8" ),
    ID_ID( "Indonesia", "Indonesian", "id_ID.UTF-8" ),
    IG_NG( "Nigeria", "Igbo", "ig_NG.UTF-8" ),
    IK_CA( "Canada", "Inupiaq", "ik_CA.UTF-8" ),
    IS_IS( "Iceland", "Icelandic", "is_IS.UTF-8" ),
    IT_CH( "Switzerland", "Italian", "it_CH.UTF-8" ),
    IT_IT_EURO( "Italy", "Italian", "it_IT@euro.UTF-8" ),
    IT_IT( "Italy", "Italian", "it_IT.UTF-8" ),
    IU_CA( "Canada", "Inuktitut", "iu_CA.UTF-8" ),
    JA_JP( "Japan", "Japanese", "ja_JP.UTF-8" ),
    KA_GE( "Georgia", "Georgian", "ka_GE.UTF-8" ),
    KAB_DZ( "Algeria", "Kabyle", "kab_DZ.UTF-8" ),
    KK_KZ( "Kazakhstan", "Kazakh", "kk_KZ.UTF-8" ),
    KL_GL( "Greenland", "Kalaallisut", "kl_GL.UTF-8" ),
    KM_KH( "Cambodia", "Khmer", "km_KH.UTF-8" ),
    KN_IN( "India", "Kannada", "kn_IN.UTF-8" ),
    KO_KR( "South Korea", "Korean", "ko_KR.UTF-8" ),
    KOK_IN( "India", "Konkani", "kok_IN.UTF-8" ),
    KS_IN_DEVANAGARI( "India", "Kashmiri", "ks_IN@devanagari.UTF-8" ),
    KS_IN( "India", "Kashmiri", "ks_IN.UTF-8" ),
    KU_TR( "Turkey", "Kurdish", "ku_TR.UTF-8" ),
    KW_GB( "United Kingdom", "Cornish", "kw_GB.UTF-8" ),
    KY_KG( "Kyrgyzstan", "Kyrgyz", "ky_KG.UTF-8" ),
    LB_LU( "Luxembourg", "Luxembourgish", "lb_LU.UTF-8" ),
    LG_UG( "Uganda", "Ganda", "lg_UG.UTF-8" ),
    LI_BE( "Belgium", "Limburgish", "li_BE.UTF-8" ),
    LI_NL( "Netherlands", "Limburgish", "li_NL.UTF-8" ),
    LIJ_IT( "Italy", "Ligurian", "lij_IT.UTF-8" ),
    LN_CD( "Democratic Republic of the Congo", "Lingala", "ln_CD.UTF-8" ),
    LO_LA( "Laos", "Lao", "lo_LA.UTF-8" ),
    LT_LT( "Lithuania", "Lithuanian", "lt_LT.UTF-8" ),
    LV_LV( "Latvia", "Latvian", "lv_LV.UTF-8" ),
    LZH_TW( "Taiwan", "Literary Chinese", "lzh_TW.UTF-8" ),
    MAG_IN( "India", "Magahi", "mag_IN.UTF-8" ),
    MAI_IN( "India", "Maithili", "mai_IN.UTF-8" ),
    MAI_NP( "Nepal", "Maithili", "mai_NP.UTF-8" ),
    MFE_MU( "Mauritius", "Morisyen", "mfe_MU.UTF-8" ),
    MG_MG( "Madagascar", "Malagasy", "mg_MG.UTF-8" ),
    MHR_RU( "Russia", "Meadow Mari", "mhr_RU.UTF-8" ),
    MI_NZ( "New Zealand", "Maori", "mi_NZ.UTF-8" ),
    MIQ_NI( "Nicaragua", "Miskito", "miq_NI.UTF-8" ),
    MJW_IN( "India", "Karbi", "mjw_IN.UTF-8" ),
    MK_MK( "Macedonia", "Macedonian", "mk_MK.UTF-8" ),
    ML_IN( "India", "Malayalam", "ml_IN.UTF-8" ),
    MN_MN( "Mongolia", "Mongolian", "mn_MN.UTF-8" ),
    MNI_IN( "India", "Manipuri", "mni_IN.UTF-8" ),
    MNW_MM( "Myanmar", "Mon", "mnw_MM.UTF-8" ),
    MR_IN( "India", "Marathi", "mr_IN.UTF-8" ),
    MS_MY( "Malaysia", "Malay", "ms_MY.UTF-8" ),
    MT_MT( "malta", "Maltese", "mt_MT.UTF-8" ),
    MY_MM( "Myanmar (Burma)", "Burmese", "my_MM.UTF-8" ),
    NAN_TW_LATIN( "Taiwan", "Min Nan Chinese", "nan_TW@latin.UTF-8" ),
    NAN_TW( "Taiwan", "Min Nan Chinese", "nan_TW.UTF-8" ),
    NB_NO( "Norway", "Norwegian Bokm<U00E5>l", "nb_NO.UTF-8" ),
    NDS_DE( "Germany", "Low German", "nds_DE.UTF-8" ),
    NDS_NL( "Netherlands", "Low Saxon", "nds_NL.UTF-8" ),
    NE_NP( "Nepal", "Nepali", "ne_NP.UTF-8" ),
    NHN_MX( "Mexico", "Central Nahuatl", "nhn_MX.UTF-8" ),
    NIU_NU( "Niue", "Niuean", "niu_NU.UTF-8" ),
    NIU_NZ( "New Zealand", "Niuean", "niu_NZ.UTF-8" ),
    NL_AW( "Aruba", "Dutch", "nl_AW.UTF-8" ),
    NL_BE_EURO( "Belgium", "Dutch", "nl_BE@euro.UTF-8" ),
    NL_BE( "Belgium", "Flemish", "nl_BE.UTF-8" ),
    NL_NL_EURO( "Netherlands", "Dutch", "nl_NL@euro.UTF-8" ),
    NL_NL( "Netherlands", "Dutch", "nl_NL.UTF-8" ),
    NN_NO( "Norway", "Norwegian Nynorsk", "nn_NO.UTF-8" ),
    NR_ZA( "South Africa", "South Ndebele", "nr_ZA.UTF-8" ),
    NSO_ZA( "South Africa", "Northern Sotho", "nso_ZA.UTF-8" ),
    OC_FR( "France", "Occitan", "oc_FR.UTF-8" ),
    OM_ET( "Ethiopia", "Oromo", "om_ET.UTF-8" ),
    OM_KE( "Kenya", "Oromo", "om_KE.UTF-8" ),
    OR_IN( "India", "Odia", "or_IN.UTF-8" ),
    OS_RU( "Russia", "Ossetic", "os_RU.UTF-8" ),
    PA_IN( "India", "Punjabi", "pa_IN.UTF-8" ),
    PA_PK( "Pakistan", "Punjabi", "pa_PK.UTF-8" ),
    PAP_AW( "Aruba", "Papiamento", "pap_AW.UTF-8" ),
    PAP_CW( "Cura<U00E7>ao", "Papiamento", "pap_CW.UTF-8" ),
    PL_PL( "Poland", "Polish", "pl_PL.UTF-8" ),
    PS_AF( "Afghanistan", "Pashto", "ps_AF.UTF-8" ),
    PT_BR( "Brazil", "Brazilian Portuguese", "pt_BR.UTF-8" ),
    PT_PT_EURO( "Portugal", "Portuguese", "pt_PT@euro.UTF-8" ),
    PT_PT( "Portugal", "European Portuguese", "pt_PT.UTF-8" ),
    QUZ_PE( "Peru", "Cusco Quechua", "quz_PE.UTF-8" ),
    RAJ_IN( "India", "Rajasthani", "raj_IN.UTF-8" ),
    RO_RO( "Romania", "Romanian", "ro_RO.UTF-8" ),
    RU_RU( "Russia", "Russian", "ru_RU.UTF-8" ),
    RU_UA( "Ukraine", "Russian", "ru_UA.UTF-8" ),
    RW_RW( "Rwanda", "Kinyarwanda", "rw_RW.UTF-8" ),
    SA_IN( "India", "Sanskrit", "sa_IN.UTF-8" ),
    SAH_RU( "Russian Federation", "Sakha", "sah_RU.UTF-8" ),
    SAT_IN( "India", "Santali", "sat_IN.UTF-8" ),
    SC_IT( "Italy", "Sardinian", "sc_IT.UTF-8" ),
    SD_IN_DEVANAGARI( "India", "Sindhi", "sd_IN@devanagari.UTF-8" ),
    SD_IN( "India", "Sindhi", "sd_IN.UTF-8" ),
    SE_NO( "Norway", "Northern Sami", "se_NO.UTF-8" ),
    SGS_LT( "Lithuania", "Samogitian", "sgs_LT.UTF-8" ),
    SHN_MM( "Myanmar", "Shan", "shn_MM.UTF-8" ),
    SHS_CA( "Canada", "Shuswap", "shs_CA.UTF-8" ),
    SI_LK( "Sri Lanka", "Sinhala", "si_LK.UTF-8" ),
    SID_ET( "Ethiopia", "Sidamo", "sid_ET.UTF-8" ),
    SK_SK( "Slovakia", "Slovak", "sk_SK.UTF-8" ),
    SL_SI( "Slovenia", "Slovenian", "sl_SI.UTF-8" ),
    SM_WS( "Samoa", "Samoan", "sm_WS.UTF-8" ),
    SO_DJ( "Djibouti", "Somali", "so_DJ.UTF-8" ),
    SO_ET( "Ethiopia", "Somali", "so_ET.UTF-8" ),
    SO_KE( "Kenya", "Somali", "so_KE.UTF-8" ),
    SO_SO( "Somalia", "Somali", "so_SO.UTF-8" ),
    SQ_AL( "Albania", "Albanian", "sq_AL.UTF-8" ),
    SQ_MK( "Macedonia", "Albanian", "sq_MK.UTF-8" ),
    SR_ME( "Montenegro", "Serbian", "sr_ME.UTF-8" ),
    SR_RS_LATIN( "Serbia", "Serbian", "sr_RS@latin.UTF-8" ),
    SR_RS( "Serbia", "Serbian", "sr_RS.UTF-8" ),
    SS_ZA( "South Africa", "Swati", "ss_ZA.UTF-8" ),
    ST_ZA( "South Africa", "Southern Sotho", "st_ZA.UTF-8" ),
    SV_FI_EURO( "Finland", "Swedish", "sv_FI@euro.UTF-8" ),
    SV_FI( "Finland", "Swedish", "sv_FI.UTF-8" ),
    SV_SE( "Sweden", "Swedish", "sv_SE.UTF-8" ),
    SW_KE( "Kenya", "Swahili", "sw_KE.UTF-8" ),
    SW_TZ( "Tanzania", "Swahili", "sw_TZ.UTF-8" ),
    SZL_PL( "Poland", "Silesian", "szl_PL.UTF-8" ),
    TA_IN( "India", "Tamil", "ta_IN.UTF-8" ),
    TA_LK( "Sri Lanka", "Tamil", "ta_LK.UTF-8" ),
    TCY_IN( "India", "Tulu", "tcy_IN.UTF-8" ),
    TE_IN( "India", "Telugu", "te_IN.UTF-8" ),
    TG_TJ( "Tajikistan", "Tajik", "tg_TJ.UTF-8" ),
    TH_TH( "Thailand", "Thai", "th_TH.UTF-8" ),
    THE_NP( "Nepal", "Chitwania Tharu", "the_NP.UTF-8" ),
    TI_ER( "Eritrea", "Tigrinya", "ti_ER.UTF-8" ),
    TI_ET( "Ethiopia", "Tigrinya", "ti_ET.UTF-8" ),
    TIG_ER( "Eritrea", "Tigre", "tig_ER.UTF-8" ),
    TK_TM( "Turkmenistan", "Turkmen", "tk_TM.UTF-8" ),
    TL_PH( "Philippines", "Tagalog", "tl_PH.UTF-8" ),
    TN_ZA( "South Africa", "Tswana", "tn_ZA.UTF-8" ),
    TO_TO( "Tonga", "Tongan", "to_TO.UTF-8" ),
    TPI_PG( "Papua New Guinea", "Tok Pisin", "tpi_PG.UTF-8" ),
    TR_CY( "Cyprus", "Turkish", "tr_CY.UTF-8" ),
    TR_TR( "Turkey", "Turkish", "tr_TR.UTF-8" ),
    TS_ZA( "South Africa", "Tsonga", "ts_ZA.UTF-8" ),
    TT_RU_IQTELIF( "Russia", "Tatar", "tt_RU@iqtelif.UTF-8" ),
    TT_RU( "Russia", "Tatar", "tt_RU.UTF-8" ),
    UG_CN( "China", "Uyghur", "ug_CN.UTF-8" ),
    UK_UA( "Ukraine", "Ukrainian", "uk_UA.UTF-8" ),
    UNM_US( "United States", "Unami Delaware", "unm_US.UTF-8" ),
    UR_IN( "India", "Urdu", "ur_IN.UTF-8" ),
    UR_PK( "Pakistan", "Urdu", "ur_PK.UTF-8" ),
    UZ_UZ_CYRILLIC( "Uzbekistan", "Uzbek", "uz_UZ@cyrillic.UTF-8" ),
    UZ_UZ( "Uzbekistan", "Uzbek", "uz_UZ.UTF-8" ),
    VE_ZA( "South Africa", "Venda", "ve_ZA.UTF-8" ),
    VI_VN( "Vietnam", "Vietnamese", "vi_VN.UTF-8" ),
    WA_BE_EURO( "Belgium", "Walloon", "wa_BE@euro.UTF-8" ),
    WA_BE( "Belgium", "Walloon", "wa_BE.UTF-8" ),
    WAE_CH( "Switzerland", "Walser", "wae_CH.UTF-8" ),
    WAL_ET( "Ethiopia", "Wolaytta", "wal_ET.UTF-8" ),
    WO_SN( "Senegal", "Wolof", "wo_SN.UTF-8" ),
    XH_ZA( "South Africa", "Xhosa", "xh_ZA.UTF-8" ),
    YI_US( "United States", "Yiddish", "yi_US.UTF-8" ),
    YO_NG( "Nigeria", "Yoruba", "yo_NG.UTF-8" ),
    YUE_HK( "Hong Kong SAR China", "Cantonese", "yue_HK.UTF-8" ),
    YUW_PG( "Papua New Guinea", "Yau", "yuw_PG.UTF-8" ),
    ZH_CN( "China", "Chinese", "zh_CN.UTF-8" ),
    ZH_HK( "Hong Kong SAR China", "Chinese", "zh_HK.UTF-8" ),
    ZH_SG( "Singapore", "Chinese", "zh_SG.UTF-8" ),
    ZH_TW( "Taiwan", "Chinese", "zh_TW.UTF-8" ),
    ZU_ZA( "South Africa", "Zulu", "zu_ZA.UTF-8" );

    public static final ApplicationLocale DEFAULT_LOCALE = EN_US;

    public static final String UTF_8 = ".UTF-8";

    public static final String UTF8 = ".UTF8";

    private String country;

    private String language;

    private String locale;

    private ApplicationLocale( String country, String language, String locale )
    {
        this.country = country;
        this.language = language;
        this.locale = locale;
    }

    public static final ApplicationLocale getApplicationLocale( String locale )
    {
        for ( ApplicationLocale applicationLocale : values() )
        {
            if ( StringUtils.equals( applicationLocale.getLocale(), StringUtils.join( locale, UTF_8 ) ) || StringUtils.equals( applicationLocale.getLocale(), StringUtils.join( locale, UTF8 ) ) )
            {
                return applicationLocale;
            }
        }
        return DEFAULT_LOCALE;
    }

    public String getCountry()
    {
        return country;
    }

    public String getLanguage()
    {
        return language;
    }

    public String getLocale()
    {
        return locale;
    }

}
