/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.info;

import java.util.Locale;

import org.apache.commons.lang3.StringUtils;

public enum TranslationLocale
{

    EN_US( new Locale( "en", "US" ) ), SL_SI( new Locale( "sl", "SI" ) );

    public static final TranslationLocale DEFAULT_LOCALE = EN_US;

    private Locale locale;

    private TranslationLocale( Locale locale )
    {
        this.locale = locale;
    }

    public static final TranslationLocale getTranslationLocale( String locale )
    {
        String language = StringUtils.split( locale, "_" )[0];
        String country = StringUtils.split( locale, "_" )[1];
        Locale l = StringUtils.isNotBlank( locale ) ? new Locale( language, country ) : DEFAULT_LOCALE.getLocale();
        for ( TranslationLocale translationLocale : values() )
        {
            if ( translationLocale.getLocale()
                                  .equals( l ) )
            {
                return translationLocale;
            }
        }
        return DEFAULT_LOCALE;
    }

    public Locale getLocale()
    {
        return locale;
    }

}
