/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.login;

import java.util.Objects;

import org.apache.commons.lang3.StringUtils;
import org.dussan.vaadin.dvirtual.i18n.Translation;
import org.dussan.vaadin.dvirtual.i18n.TranslationProvider;
import org.dussan.vaadin.dvirtual.info.TranslationLocale;

import com.vaadin.flow.component.login.LoginForm;
import com.vaadin.flow.component.login.LoginI18n;

public class UserLogin
    extends LoginForm
{

    private static final long serialVersionUID = 1968656746601141704L;

    boolean loginEnabled = true;

    boolean signIn = false;

    private String title = null;

    private String password = null;

    private String username = null;

    public UserLogin()
    {
        password = StringUtils.EMPTY;
        username = StringUtils.EMPTY;
        setForgotPasswordButtonVisible( false );
    }

    public UserLogin( String username, String password )
    {
        this();
        this.username = username;
        this.password = password;
    }

    public void setTranslationLocale( TranslationLocale translationLocale )
    {
        if ( Objects.nonNull( translationLocale ) )
        {
            TranslationProvider translationProvider = new TranslationProvider();
            translationProvider.setTranslationLocale( translationLocale );
            LoginI18n loginI18n = LoginI18n.createDefault();
            loginI18n.setHeader( new LoginI18n.Header() );
            loginI18n.getForm()
                     .setUsername( translationProvider.getTranslation( Translation.LOGIN_USERNAME ) );
            loginI18n.getForm()
                     .setTitle( StringUtils.defaultIfBlank( getTitle(), translationProvider.getTranslation( Translation.LOGIN_TITLE ) ) );
            loginI18n.getForm()
                     .setSubmit( translationProvider.getTranslation( Translation.LOGIN_SUBMIT ) );
            loginI18n.getForm()
                     .setPassword( translationProvider.getTranslation( Translation.LOGIN_PAZZWORD ) );
            loginI18n.getForm()
                     .setForgotPassword( translationProvider.getTranslation( Translation.LOGIN_PAZZWORD_FORGOT ) );
            loginI18n.getErrorMessage()
                     .setTitle( translationProvider.getTranslation( Translation.LOGIN_ERROR_TITLE ) );
            loginI18n.getErrorMessage()
                     .setMessage( translationProvider.getTranslation( Translation.LOGIN_ERROR_MESSAGE ) );
            setI18n( loginI18n );
        }
    }

    public boolean isLoginEnabled()
    {
        return loginEnabled;
    }

    public void setLoginEnabled( boolean loginEnabled )
    {
        this.loginEnabled = loginEnabled;
    }

    public boolean isSignIn()
    {
        return signIn;
    }

    public void setSignIn( boolean signIn )
    {
        this.signIn = signIn;
    }

    public String getPassword()
    {
        return password;
    }

    public void setPassword( String password )
    {
        this.password = password;
    }

    public String getUsername()
    {
        return username;
    }

    public void setUsername( String username )
    {
        this.username = username;
    }

    public String getTitle()
    {
        return title;
    }

    public void setTitle( String title )
    {
        this.title = title;
    }

}
