/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.logout;

import org.dussan.vaadin.dvirtual.i18n.Translation;
import org.dussan.vaadin.dvirtual.utils.VirtualUtil;
import org.dussan.vaadin.dvirtual.utils.dialog.common.DialogUtil;

import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.html.Div;
import com.vaadin.flow.component.icon.Icon;
import com.vaadin.flow.component.icon.VaadinIcon;
import com.vaadin.flow.component.orderedlayout.HorizontalLayout;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.component.orderedlayout.FlexComponent.Alignment;
import com.vaadin.flow.component.orderedlayout.FlexComponent.JustifyContentMode;

public abstract class LogOutUserDialog
    extends DialogUtil
{

    private static final long serialVersionUID = 6510571351815496003L;

    private static final String ATTRIBUTE_CLASS_BUTTON_VALUE = "primary";

    private static final String ATTRIBUTE_THEME = "theme";

    private static final String ATTRIBUTE_THEME_VALUE = "dark";

    private static final String DIALOG_HEIGHT = "auto";

    private static final String DIALOG_WIDTH = "auto";

    private static final String INNER_HTML = "innerHTML";

    private static final String STYLE_COLOR = "color";

    private static final String STYLE_COLOR_VALUE = "rgb(42, 127, 239)";

    private static final String STYLE_FONT_SIZE = "font-size";

    private static final String STYLE_FONT_SIZE_VALUE = "var(--lumo-font-size-l)";

    private static final String STYLE_ICON_SIZE = "42px";

    private static final String STYLE_MARGIN_BOTTOM = "margin-bottom";

    private static final String STYLE_MARGIN_LEFT = "margin-left";

    private static final String STYLE_MARGIN_RIGHT = "margin-right";

    private static final String STYLE_MARGIN_VALUE = "0px";

    private static final String STYLE_MAX_WIDTH = "max-width";

    private static final String STYLE_PADDING_BOTTOM = "padding-bottom";

    private static final String STYLE_PADDING_RIGHT = "padding-right";

    private static final String STYLE_PADDING_VALUE = "0px";

    private static final String STYLE_WIDTH = "width";

    private static final String STYLE_WIDTH_100PERCENT_VALUE = "100%";

    private static final String STYLE_WIDTH_50PX_VALUE = "50px";

    private static final String STYLE_WIDTH_600PX_VALUE = "600px";

    public LogOutUserDialog( VirtualUtil virtualUtil )
    {
        setCloseOnEsc( true );
        setWidth( DIALOG_WIDTH );
        setHeight( DIALOG_HEIGHT );

        Icon icon = new Icon( VaadinIcon.EXCLAMATION_CIRCLE_O );
        icon.setSize( STYLE_ICON_SIZE );
        icon.getStyle()
            .set( STYLE_COLOR, STYLE_COLOR_VALUE )
            .set( STYLE_WIDTH, STYLE_WIDTH_50PX_VALUE );

        Div messageDiv = new Div();
        messageDiv.getElement()
                  .getStyle()
                  .set( STYLE_FONT_SIZE, STYLE_FONT_SIZE_VALUE );
        messageDiv.getElement()
                  .setProperty( INNER_HTML, virtualUtil.getTranslation( Translation.LOGOUT_APPLICATIONS ) );

        HorizontalLayout messageLayout = new HorizontalLayout( icon, messageDiv );
        messageLayout.setDefaultVerticalComponentAlignment( Alignment.CENTER );
        messageLayout.setSizeFull();

        // cancel
        Button cancelButton = new Button( virtualUtil.getTranslation( Translation.BUTTON_CANCEL ), event -> close() );
        cancelButton.getElement()
                    .setAttribute( ATTRIBUTE_THEME, ATTRIBUTE_THEME_VALUE );

        // close applications
        Button closeApplicationsButton = new Button( virtualUtil.getTranslation( Translation.BUTTON_APPLICATIONS_CLOSE ), event -> {
            closeAllAplications( true );
            close();
        } );
        closeApplicationsButton.addClassName( ATTRIBUTE_CLASS_BUTTON_VALUE );
        closeApplicationsButton.setAutofocus( true );
        closeApplicationsButton.setDisableOnClick( true );
        closeApplicationsButton.getElement()
                               .setAttribute( ATTRIBUTE_THEME, ATTRIBUTE_THEME_VALUE );
        closeApplicationsButton.getStyle()
                               .set( STYLE_MARGIN_LEFT, STYLE_MARGIN_VALUE );

        // leave applications
        Button leaveApplicationsButton = new Button( virtualUtil.getTranslation( Translation.BUTTON_APPLICATIONS_LEAVE ), event -> {
            closeAllAplications( false );
            close();
        } );
        leaveApplicationsButton.setDisableOnClick( true );
        leaveApplicationsButton.getElement()
                               .setAttribute( ATTRIBUTE_THEME, ATTRIBUTE_THEME_VALUE );

        HorizontalLayout buttonsLayout = new HorizontalLayout( closeApplicationsButton, leaveApplicationsButton, cancelButton );
        buttonsLayout.setJustifyContentMode( JustifyContentMode.CENTER );
        buttonsLayout.setMargin( true );
        buttonsLayout.setPadding( true );
        buttonsLayout.setSpacing( true );
        buttonsLayout.setWidth( STYLE_WIDTH_100PERCENT_VALUE );
        buttonsLayout.getStyle()
                     .set( STYLE_MARGIN_BOTTOM, STYLE_MARGIN_VALUE )
                     .set( STYLE_MARGIN_LEFT, STYLE_MARGIN_VALUE )
                     .set( STYLE_MARGIN_RIGHT, STYLE_MARGIN_VALUE )
                     .set( STYLE_PADDING_BOTTOM, STYLE_PADDING_VALUE )
                     .set( STYLE_PADDING_RIGHT, STYLE_PADDING_VALUE );

        VerticalLayout mainLayout = new VerticalLayout( messageLayout, buttonsLayout );
        mainLayout.setMargin( false );
        mainLayout.setPadding( false );
        mainLayout.setSpacing( true );
        mainLayout.setSizeUndefined();
        mainLayout.setWidth( STYLE_WIDTH_100PERCENT_VALUE );
        mainLayout.getStyle()
                  .set( STYLE_MAX_WIDTH, STYLE_WIDTH_600PX_VALUE );

        add( mainLayout );
    }

    public abstract void closeAllAplications( boolean closeAllAplications );

}
