/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.io.brotli;

import java.io.IOException;
import java.io.InputStream;
import java.io.Serializable;
import java.util.Arrays;

import org.apache.commons.compress.compressors.brotli.BrotliCompressorInputStream;

public class PatchBrotliChunk
    implements Serializable
{

    private static final long serialVersionUID = 6915930547201703487L;

    public PatchBrotliChunk()
    {
        // nothing to do
    }

    @SuppressWarnings( "resource" )
    public byte[] readPatch( InputStream inputStream )
        throws IOException
    {
        int index = 0;
        int byteValue = -1;
        byte[] buffer = new byte[0];
        BrotliCompressorInputStream brotliCompressorInputStream = new BrotliCompressorInputStream( inputStream );
        do
        {
            byteValue = brotliCompressorInputStream.read();
            if ( byteValue >= 0 )
            {
                buffer = Arrays.copyOf( buffer, index + 1 );
                buffer[index++] = (byte) byteValue;
            }
        }
        while ( byteValue >= 0 );
        return buffer;
    }

}
