/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets;

import org.apache.commons.lang3.StringUtils;

public class PacketType
{

    public enum Client
    {
        BUTTON_ACTION( "button-action" ),
        CLIPBOARD_CONTENTS( "clipboard-contents" ),
        CLIPBOARD_CONTENTS_NONE( "clipboard-contents-none" ),
        CLIPBOARD_TOKEN( "clipboard-token" ),
        CLOSE_WINDOW( "close-window" ),
        CONFIGURE_WINDOW( "configure-window" ),
        DAMAGE_SEQUENCE( "damage-sequence" ),
        DESKTOP_SIZE( "desktop_size" ),
        DISCONNECT( "disconnect" ),
        FOCUS( "focus" ),
        HELLO( "hello" ),
        KEY_ACTION( "key-action" ),
        MAP_WINDOW( "map-window" ),
        PING( "ping" ),
        PING_ECHO( "ping_echo" ),
        POINTER_POSITION( "pointer-position" ),
        RESUME( "resume" ),
        SET_DEFLATE( "set_deflate" ),
        SUSPEND( "suspend" ),
        UNMAP_WINDOW( "unmap-window" ),
        WHEEL_MOTION( "wheel-motion" );

        private String type;

        Client( String type )
        {
            this.type = type;
        }

        public static Client getType( String type )
        {
            for ( Client client : Client.values() )
            {
                if ( StringUtils.equals( client.toString(), type ) )
                {
                    return client;
                }
            }
            return null;
        }

        @Override
        public String toString()
        {
            return type.toLowerCase();
        }
    }

    public enum Server
    {
        CLIPBOARD_REQUEST( "clipboard-request" ),
        CLIPBOARD_TOKEN( "clipboard-token" ),
        CONFIGURE_OVERRIDE_REDIRECT( "configure-override-redirect" ),
        CURSOR( "cursor" ),
        DESKTOP_SIZE( "desktop_size" ),
        DRAW( "draw" ),
        DISCONNECT( "disconnect" ),
        ENCODINGS( "encodings" ),
        EOS( "eos" ),
        HELLO( "hello" ),
        LOST_WINDOW( "lost-window" ),
        NEW_OVERRIDE_REDIRECT( "new-override-redirect" ),
        NEW_WINDOW( "new-window" ),
        PING( "ping" ),
        PING_ECHO( "ping_echo" ),
        RAISE_WINDOW( "raise-window" ),
        SET_CLIPBOARD_ENABLED( "set-clipboard-enabled" ),
        SET_DEFLATE( "set_deflate" ),
        STARTUP_COMPLETE( "startup-complete" ),
        WINDOW_ICON( "window-icon" ),
        WINDOW_METADATA( "window-metadata" ),
        WINDOW_MOVE_RESIZE( "window-move-resize" ),
        WINDOW_RESIZED( "window-resized" );

        private String type;

        Server( String type )
        {
            this.type = type;
        }

        public static Server getType( String type )
        {
            for ( Server server : Server.values() )
            {
                if ( StringUtils.equals( server.toString(), type ) )
                {
                    return server;
                }
            }
            return null;
        }

        @Override
        public String toString()
        {
            return type.toLowerCase();
        }
    }

}
