/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.xpra.packets.client;

import java.util.Collection;

import org.apache.commons.lang3.StringUtils;
import org.dussan.vaadin.dvirtual.xpra.packets.ClientPacket;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;
import org.dussan.vaadin.dvirtual.xpra.packets.server.ServerDrawPacket;

public class ClientDamageSequencePacket
    extends ClientPacket
{

    private static final long serialVersionUID = -4100401974119590449L;

    public static final int SEQUENCE_FRAME_TIME_FACTOR = 1000;

    public static final int SEQUENCE_FRAME_UNDEFINED = -1;

    private int height = 0;

    private int packetSequence;

    private int width = 0;

    private int windowId = 0;

    private long frameTime = 0;

    private String message = null;

    public ClientDamageSequencePacket()
    {
        super( PacketType.Client.DAMAGE_SEQUENCE.toString() );
    }

    public ClientDamageSequencePacket( ServerDrawPacket packet, long frameTime )
    {
        super( PacketType.Client.DAMAGE_SEQUENCE.toString() );
        this.windowId = packet.getWindowId();
        this.width = packet.getWidth();
        this.height = packet.getHeight();
        this.packetSequence = packet.getPacketSequence();
        this.frameTime = frameTime;
        this.message = getMessage();
    }

    public ClientDamageSequencePacket( int windowId, int width, int height, int packetSequence, long frameTime, String message )
    {
        super( PacketType.Client.DAMAGE_SEQUENCE.toString() );
        this.windowId = windowId;
        this.width = width;
        this.height = height;
        this.packetSequence = packetSequence;
        this.frameTime = frameTime;
        this.message = message;
    }

    public long getFrameTime()
    {
        return frameTime;
    }

    public int getHeight()
    {
        return height;
    }

    public String getMessage()
    {
        return StringUtils.defaultIfBlank( message, StringUtils.EMPTY );
    }

    public int getPacketSequence()
    {
        return packetSequence;
    }

    public int getWidth()
    {
        return width;
    }

    public int getWindowId()
    {
        return windowId;
    }

    @Override
    public void packPacket( Collection<Object> packetData )
    {
        packetData.add( getPacketType() );
        packetData.add( getPacketSequence() );
        packetData.add( getWindowId() );
        packetData.add( getWidth() );
        packetData.add( getHeight() );
        packetData.add( getFrameTime() );
        packetData.add( getMessage() );
    }

}
